<?php

/**
 * Register Featured Block Page
 */
function register_featured_block_submenu_page() {
	add_submenu_page( 'colabsthemes', __('Featured Block Settings', 'colabsthemes'), __('Featured Block'), 'manage_options', 'featured_block', 'colabs_featured_block_page' );
}
add_action( 'admin_menu', 'register_featured_block_submenu_page' );

/**
 * Featured Block Page
 */
function colabs_featured_block_page() {
	locate_template( 'includes/featured-block/views/featured_block_page.php', true );
}

/**
 * Save featured block
 */
function colabs_save_featured_block() {
	$featured_block = array();

	if( isset( $_POST['page'] ) && 'featured_block' == $_POST['page'] ) {
		if( isset( $_POST['colabs_block_item_title'] ) ) {
			for ($i=0; $i < count($_POST['colabs_block_item_title']); $i++) { 
				$featured_block[$i]['block_title'] = $_POST['colabs_block_item_title'][$i];
				$featured_block[$i]['block_url'] = $_POST['colabs_block_item_url'][$i];
				$featured_block[$i]['block_image'] = $_POST['colabs_block_item_image'][$i];
				if( isset( $_POST['colabs_block_item_image_id'] ) ) {
					$featured_block[$i]['block_image_id'] = $_POST['colabs_block_item_image_id'][$i];
				}
			}
		}

		update_option( 'colabs_featured_block_list', $featured_block );
	}
}
add_action( 'admin_head-opulence_page_featured_block', 'colabs_save_featured_block' );


/**
 * Featured Block Page Scripts and Styles
 */
function colabs_featured_block_admin_head() {
	
	// Enqueue Styles
	echo '<link rel="stylesheet" type="text/css" href="' . get_template_directory_uri() . '/functions/admin-style.css" media="screen">';
	echo '<link rel="stylesheet" type="text/css" href="' . get_template_directory_uri() . '/includes/featured-block/css/admin-featuredblock-style.css" media="screen">';

	// Enqueue Javacripts
	// ------------------
	wp_enqueue_script( 'jquery-ui-core' );
	wp_enqueue_script( 'jquery-ui-sortable' );
	wp_enqueue_script( 'jquery-ui-droppable' );	
	wp_enqueue_script( 'colabs-scripts', get_template_directory_uri() .'/functions/js/colabs-scripts.js', array( 'jquery' ));
	wp_enqueue_script( 'colabs-featured-scripts', get_template_directory_uri() .'/includes/featured-block/js/colabs-admin-featured-block.js', array( 'jquery' ));

}
add_action( 'admin_head-opulence_page_featured_block', 'colabs_featured_block_admin_head' );

// Add Media Uploader
function featured_add_media_uploader($hook) {
	if ( ! did_action( 'wp_enqueue_media' ) && 'opulence_page_featured_block' == $hook )
		wp_enqueue_media();
}
add_action( 'admin_enqueue_scripts', 'featured_add_media_uploader' );


/**
 * List All Featured Block
 *
 * @return Array Array of featured block
 */
function colabs_get_featured_block() {
	return get_option( 'colabs_featured_block_list' );
}

/**
 * Render featured block list on Admin page
 */
function colabs_render_featured_block_admin() {
	$block_list = colabs_get_featured_block();
	if( $block_list ) { 
		foreach( $block_list as $block ) {
			colabs_featured_block_html( $block );
		}
	}
}

/**
 * HTML for block list on Admin page
 */
function colabs_featured_block_html( $data = array() ) {
	$is_clone = $data ? '' : 'block-clone';
	$default = array(
		'block_image' => 'http://placehold.it/100x100',
		'block_image_id' => '',
		'block_title' => 'Block Title',
		'block_url' => ''
	);
	$data = wp_parse_args( $data, $default ); 
	extract( $data ); ?>
	
	<li class="block-item <?php echo $is_clone; ?>">
		<div class="block-item-info">
			<div class="block-image">
				<img src="<?php echo $block_image; ?>" width="100">
			</div>
			<div class="block-item-content">
				<h3 class="block-item-title"><?php echo $block_title; ?></h3>
				<a href="<?php echo $block_url; ?>"><?php echo $block_url; ?></a>
			</div>
			<div class="block-item-action">
				<a href="#edit-block" class="button edit-block"><?php _e('Edit', 'colabsthemes'); ?></a>
				<a href="#delete-block" class="button delete-block"><?php _e('Delete', 'colabsthemes'); ?></a>
			</div>
		</div>

		<div class="block-item-form">
			<div class="input-type-text">
				<label>Title:</label>
				<input type="text" name="colabs_block_item_title[]" value="<?php echo $block_title; ?>">
			</div>
			<div class="input-type-text">
				<label>URL:</label>
				<span class="label-prepend">http://</span>
				<input type="text" name="colabs_block_item_url[]" class="input-prepend" value="<?php echo $block_url; ?>">
			</div>
			<div class="input-type-text">
				<label>Image:</label>
				<input type="hidden" name="colabs_block_item_image_id[]" value="<?php echo $block_image_id; ?>">
				<input type="text" name="colabs_block_item_image[]" class="input-upload" value="<?php echo $block_image; ?>">
				<a href="#change-image" class="button change-block-image"><?php _e('Add Image', 'colabsthemes'); ?></a>
			</div>
		</div>
	</li>

	<?php
}