(function($){

"use strict";

var block_options;

block_options = {
	el: {
		$body: $('body'),
		$block_list: $('.featured-block-list'),
		$block_clone: $('.block-clone')
	},

	event_binding: function() {
		this.el.$body.on('click', '.add_block_button', $.proxy(this.clone_block, this));
		this.el.$body.on('keyup', '.block-item-form :text', $.proxy(this.update_block_data, this));
		this.el.$body.on('click', '.change-block-image', $.proxy(this.add_image, this));
		this.el.$body.on('click', '.edit-block', $.proxy(this.toggle_edit, this));
		this.el.$body.on('click', '.delete-block', $.proxy(this.delete_block, this));
	},

	/**
	 * Clone block item when adding new block
	 */
	clone_block: function(e) {
		e.preventDefault();
		var $cloned = this.el.$block_clone.clone().removeClass('block-clone').addClass('block-open').appendTo( this.el.$block_list );
		$cloned.find('input:first').focus();
		$('body, html').animate({
			scrollTop: $cloned.offset().top
		})
	},

	/**
	 * Update block data when user editing the block item form
	 */
	update_block_data: function(e) {
		var $input = $(e.currentTarget),
				input_value = $input.val(),
				input_name = $input.attr('name'),
				$block_parent = $input.closest('.block-item-form').prev()

		// Update corresponding data
		switch (input_name) {
			case 'colabs_block_item_title[]':
				$block_parent.find('h3').text( input_value );
				break;
			case 'colabs_block_item_url[]':
				$block_parent.find('.block-item-content a').attr('href', 'http://' + input_value).text('http://' + input_value);
				break;
			case 'colabs_block_item_image[]':
				$block_parent.find('img').attr('src', input_value );
				break;
		}
	},

	/**
	 * Use WordPress media manager for adding image for block item
	 */
	file_frame: undefined,
	$upload_button: undefined,
	add_image: function(e) {
		e.preventDefault();
		var _this = this;

		this.$upload_button = $(e.currentTarget);

		// If media frame already exists, reopen it.
		if( this.file_frame ) {
			this.file_frame.open();
			return;
		}

		// Create the media frame
		this.file_frame = wp.media.frames.featured_block_image = wp.media({
			title: 'Choose an image',
			button: {
				text: 'Use image'
			},
			multiple: false
		});

		// When an image is selected
		this.file_frame.on('select', function() {
			var selected_image = _this.file_frame.state().get('selection').first().toJSON();

			_this.$upload_button
				.prev(':text').val(selected_image.url)
				.prev(':hidden').val(selected_image.id).end().end()
				.closest('.block-item-form').prev().find('img').attr('src', selected_image.url);
		});

		// Open the frame
		this.file_frame.open();
	},

	/**
	 * Toggle edit form
	 */
	toggle_edit: function(e) {
		e.preventDefault();
		$(e.currentTarget)
			.closest('.block-item').toggleClass('block-open')
		 	.siblings('.block-item').removeClass('block-open');
	},

	/**
	 * Delete Block
	 */
	delete_block: function(e) {
		e.preventDefault();
		$(e.currentTarget).closest('.block-item').fadeTo( 250, 0, function(){
			$(this).slideUp(250, function(){
				$(this).remove();
			});
		});
	},

	init: function() {
		this.event_binding();

		$('.featured-block-list').sortable({
			placeholder: 'featured-block-placeholder',
			start: function(e, ui){
        ui.placeholder.height(ui.item.height());
	    }
		});
	}
}

$(document).ready(function(){
	block_options.init();
});

})(jQuery);